@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERSYLPHEEDTEST_H
-#define FILTERSYLPHEEDTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -21,5 +20,3 @@ private Q_SLOTS:
     void canNotImportDataUnknowPath();
     void canNotImportDataWhenHomeDirSelected();
 };
-
-#endif // FILTERSYLPHEEDTEST_H
